==> react-molecule-accordion-1.9.0.tgz: package/lib/Tab/index.js <==
import React from 'react';
import cx from 'classnames';
var BASE_CLASS = 'sui-MoleculeAccordion-tab';
var CONTENT_CLASS = BASE_CLASS + "Content";
var CONTENT_CONTAINER_CLASS = CONTENT_CLASS + "Container";
var CONTAINER_BUTTON_CLASS = BASE_CLASS + "TitleContainer";
var OPEN_CLASS = 'is-open';
var BUTTON_CLASS = BASE_CLASS + "Btn";
var BUTTON_CONTENT_CLASS = BUTTON_CLASS + "Content";
var BUTTON_TITLE_CLASS = BUTTON_CLASS + "Title";
var ICON_CLASS = BASE_CLASS + "Icon";
var MAX_HEIGHT = 100;

var Tab = function Tab(_ref) {
  var _cx, _cx2, _cx3, _cx4;

  var onToggle = _ref.onToggle,
      children = _ref.children,
      icon = _ref.icon,
      title = _ref.title,
      withScrollVisible = _ref.withScrollVisible,
      withTransition = _ref.withTransition,
      isOpen = _ref.isOpen,
      maxHeight = _ref.maxHeight,
      autoHeight = _ref.autoHeight,
      withGap = _ref.withGap,
      _ref$withMultilineLab = _ref.withMultilineLabel,
      withMultilineLabel = _ref$withMultilineLab === void 0 ? false : _ref$withMultilineLab;
  var wrapperClassName = cx(BASE_CLASS, (_cx = {}, _cx[OPEN_CLASS] = isOpen, _cx[BASE_CLASS + "--withGap"] = withGap, _cx[BASE_CLASS + "--withMultilineLabel"] = withMultilineLabel, _cx));
  var iconClassName = cx(ICON_CLASS, (_cx2 = {}, _cx2[OPEN_CLASS] = isOpen, _cx2));
  var containerClassName = cx(CONTAINER_BUTTON_CLASS, (_cx3 = {}, _cx3[OPEN_CLASS] = isOpen, _cx3));
  var contentClassName = cx(CONTENT_CONTAINER_CLASS, (_cx4 = {}, _cx4[CONTENT_CONTAINER_CLASS + "--withTransition"] = withTransition, _cx4[CONTENT_CONTAINER_CLASS + "--withScrollVisible"] = withScrollVisible, _cx4));
  var maxHeightType = autoHeight ? '' : maxHeight + "px";
  var containerHeight = isOpen ? maxHeightType : "0px";
  return /*#__PURE__*/React.createElement("div", {
    className: wrapperClassName
  }, /*#__PURE__*/React.createElement("div", {
    className: containerClassName
  }, /*#__PURE__*/React.createElement("button", {
    type: "button",
    className: BUTTON_CLASS,
    onClick: onToggle
  }, /*#__PURE__*/React.createElement("span", {
    className: BUTTON_CONTENT_CLASS,
    tabIndex: "-1"
  }, /*#__PURE__*/React.createElement("span", {
    className: BUTTON_TITLE_CLASS
  }, title), /*#__PURE__*/React.createElement("span", {
    className: iconClassName
  }, icon)))), /*#__PURE__*/React.createElement("div", {
    className: contentClassName,
    style: {
      maxHeight: "" + containerHeight
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: CONTENT_CLASS
  }, children)));
};

Tab.displayName = 'Tab';
Tab.defaultProps = {
  isOpen: false,
  maxHeight: MAX_HEIGHT,
  autoHeight: false,
  onToggle: function onToggle() {},
  withScrollVisible: false,
  withTransition: true,
  withGap: false
};
export default Tab;

==> react-molecule-accordion-1.11.0.tgz: package/lib/Tab/index.js <==
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import cx from 'classnames';
var BASE_CLASS = 'sui-MoleculeAccordion-tab';
var CONTENT_CLASS = BASE_CLASS + "Content";
var CONTENT_CONTAINER_CLASS = CONTENT_CLASS + "Container";
var CONTAINER_BUTTON_CLASS = BASE_CLASS + "TitleContainer";
var OPEN_CLASS = 'is-open';
var BUTTON_CLASS = BASE_CLASS + "Btn";
var BUTTON_CONTENT_CLASS = BUTTON_CLASS + "Content";
var BUTTON_TITLE_CLASS = BUTTON_CLASS + "Title";
var ICON_CLASS = BASE_CLASS + "Icon";
var MAX_HEIGHT = 100;

var Tab = function Tab(_ref) {
  var _cx, _cx2, _cx3, _cx4;

  var onToggle = _ref.onToggle,
      children = _ref.children,
      icon = _ref.icon,
      title = _ref.title,
      withScrollVisible = _ref.withScrollVisible,
      withTransition = _ref.withTransition,
      isOpen = _ref.isOpen,
      maxHeight = _ref.maxHeight,
      autoHeight = _ref.autoHeight,
      withGap = _ref.withGap,
      _ref$withMultilineLab = _ref.withMultilineLabel,
      withMultilineLabel = _ref$withMultilineLab === void 0 ? false : _ref$withMultilineLab;
  var wrapperClassName = cx(BASE_CLASS, (_cx = {}, _cx[OPEN_CLASS] = isOpen, _cx[BASE_CLASS + "--withGap"] = withGap, _cx[BASE_CLASS + "--withMultilineLabel"] = withMultilineLabel, _cx));
  var iconClassName = cx(ICON_CLASS, (_cx2 = {}, _cx2[OPEN_CLASS] = isOpen, _cx2));
  var containerClassName = cx(CONTAINER_BUTTON_CLASS, (_cx3 = {}, _cx3[OPEN_CLASS] = isOpen, _cx3));
  var contentClassName = cx(CONTENT_CONTAINER_CLASS, (_cx4 = {}, _cx4[CONTENT_CONTAINER_CLASS + "--withTransition"] = withTransition, _cx4[CONTENT_CONTAINER_CLASS + "--withScrollVisible"] = withScrollVisible, _cx4));
  var maxHeightType = autoHeight ? '' : maxHeight + "px";
  var containerHeight = isOpen ? maxHeightType : "0px";
  return /*#__PURE__*/_jsxs("div", {
    className: wrapperClassName,
    children: [/*#__PURE__*/_jsx("div", {
      className: containerClassName,
      children: /*#__PURE__*/_jsx("button", {
        type: "button",
        className: BUTTON_CLASS,
        onClick: onToggle,
        children: /*#__PURE__*/_jsxs("span", {
          className: BUTTON_CONTENT_CLASS,
          tabIndex: "-1",
          children: [/*#__PURE__*/_jsx("span", {
            className: BUTTON_TITLE_CLASS,
            children: title
          }), /*#__PURE__*/_jsx("span", {
            className: iconClassName,
            children: icon
          })]
        })
      })
    }), /*#__PURE__*/_jsx("div", {
      className: contentClassName,
      style: {
        maxHeight: "" + containerHeight
      },
      children: /*#__PURE__*/_jsx("div", {
        className: CONTENT_CLASS,
        children: children
      })
    })]
  });
};

Tab.displayName = 'Tab';
Tab.defaultProps = {
  isOpen: false,
  maxHeight: MAX_HEIGHT,
  autoHeight: false,
  onToggle: function onToggle() {},
  withScrollVisible: false,
  withTransition: true,
  withGap: false
};
export default Tab;
